@@ -1,8 +1,7 @@
 from typing import List
 
 from fastapi_pagination import Page, Params, paginate
-
-from src.pagination.page_query_model import PageQueryModel
+from page_query_model import PageQueryModel
 
 
 def paginate_list(item_list: List[any], page: int, size: int) -> PageQueryModel:
